package Net::Lumberjack;

use strict;
use warnings;

our $VERSION = '1.01'; # VERSION
# ABSTRACT: client/server protocol implementation for lumberjack


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Net::Lumberjack - client/server protocol implementation for lumberjack

=head1 VERSION

version 1.01

=head1 CLIENT

For implementing a lumberjack protocol client see L<Net::Lumberjack::Client>.

=head2 SERVER

For implementing a lumberjack protocol server see L<Net::Lumberjack::Reader>.

=head1 AUTHOR

Markus Benning <ich@markusbenning.de>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2016 by Markus Benning.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
